const char *usage_msg[] = {
	"  -a: convert EOLs and tabs in text files.",
	"  -aa: convert EOLs and tabs in ALL files.",
	"  -d: set output directory (created if needed).",
	"  -e: extract files (redundant; this is the default action).",
	"  -f: fix (remove) junk at EOF.",
	"  -F: force uncompressing in case of invalid compressed size.",
	"  -h: show this help message.",
	"  -k: keep trailing periods (dots) in filenames.",
	"  -l: list files in archive (filenames only).",
	"  -L: use lowercase filenames.",
	"  -n: extract only file #<number> (counting from 1).",
	"  -o: overwrite files (do not create file~ backups).",
	"  -p: extract to stdout (enables -q).",
	"  -q: quiet: don't print filenames during extraction/testing.",
	"  -s: split ALF file into multiple ALFs.",
	"  -t: test archive.",
	"  -v: verbose listing of archive contents.",
	"  -V: show version number.",
	"  -x: exclude <wildcard>. may be given multiple times.",
	"  --: end of options (next arg is alf-file).",
	(const char*)0
};
